@@ -7,7 +7,6 @@
 #' @docType class
 #' @importFrom R6 R6Class
 #' @import htmltools
-#' @import jsonlite
 #' @format \code{\link{R6Class}} object.
 #' @examples
 #' # This class should only be created by the pivot table.
@@ -257,7 +256,7 @@ PivotHtmlRenderer <- R6::R6Class("PivotHtmlRenderer",
              lastDataGroupInRow <- TRUE
            }
            # style info
-           if(ancg$isOutline) rhs <- outlineRowHeaderStyle
+           if(ancg$isOutline && ancg$styleAsOutline) rhs <- outlineRowHeaderStyle
            else rhs <- rowHeaderStyle
            if(!is.null(ancg$baseStyleName)) rhs <- paste0(styleNamePrefix, ancg$baseStyleName)
            rwstyl <- NULL
@@ -300,17 +299,17 @@ PivotHtmlRenderer <- R6::R6Class("PivotHtmlRenderer",
        }
        # render the cell values
        if(!(rowMerge$merge && isTRUE(rowMerge$skipCells))) {
-         isOutlineCells <- FALSE
+         styleAsOutline <- FALSE
          rgCellBaseStyleName <- NULL
          rgCellStyle <- NULL
          if(!is.null(rg)) {
-           isOutlineCells <- rg$isOutline
-           rgCellBaseStyleName <- rg$cellBaseStyleName
-           rgCellStyle <- rg$cellStyle
+           styleAsOutline <- rg$isOutline && rg$styleAsOutline
+           rgCellBaseStyleName <- rg$netCellBaseStyleName
+           rgCellStyle <- rg$netCellStyle
          }
          trowcells <- private$getCellsInRowHtml(r=r, columnCount=columnCount, exportOptions=exportOptions,
                                                 styleNamePrefix=styleNamePrefix, cellStyle=cellStyle, totalStyle=totalStyle,
-                                                isOutline=isOutlineCells, outlineCellStyle=outlineCellStyle,  mergeCells=rowMerge$mergeCells,
+                                                styleAsOutline=styleAsOutline, outlineCellStyle=outlineCellStyle,  mergeCells=rowMerge$mergeCells,
                                                 rowGroupCellBaseStyleName=rgCellBaseStyleName, rowGroupCellStyle=rgCellStyle,
                                                 includeRCFilters=includeRCFilters, includeCalculationFilters=includeCalculationFilters,
                                                 includeWorkingData=includeWorkingData, includeEvaluationFilters=includeEvaluationFilters,
@@ -328,7 +327,7 @@ PivotHtmlRenderer <- R6::R6Class("PivotHtmlRenderer",
   private = list(
     p_parentPivot = NULL,
     getCellsInRowHtml = function(r=NULL, columnCount=NULL, exportOptions=NULL, styleNamePrefix=NULL, cellStyle=NULL, totalStyle=NULL,
-                                 isOutline=FALSE, outlineCellStyle=NULL, mergeCells=FALSE, rowGroupCellBaseStyleName=NULL, rowGroupCellStyle=NULL, # the last two are forcing cell styles from the row groups (that override the default cell styles, but does not override cell styles specified on the cell)
+                                 styleAsOutline=FALSE, outlineCellStyle=NULL, mergeCells=FALSE, rowGroupCellBaseStyleName=NULL, rowGroupCellStyle=NULL, # the last two are forcing cell styles from the row groups (that override the default cell styles, but does not override cell styles specified on the cell)
                                  includeRCFilters=FALSE, includeCalculationFilters=FALSE, includeWorkingData=FALSE, includeEvaluationFilters=FALSE, includeCalculationNames=FALSE, includeRawValue=FALSE) {
        if(private$p_parentPivot$argumentCheckMode > 0) {
           checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", r, missing(r), allowMissing=FALSE, allowNull=FALSE, allowedClasses=c("integer", "numeric"))
@@ -337,7 +336,7 @@ PivotHtmlRenderer <- R6::R6Class("PivotHtmlRenderer",
           checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", styleNamePrefix, missing(styleNamePrefix), allowMissing=FALSE, allowNull=TRUE, allowedClasses="character")
           checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", cellStyle, missing(cellStyle), allowMissing=TRUE, allowNull=FALSE, allowedClasses="character")
           checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", totalStyle, missing(totalStyle), allowMissing=TRUE, allowNull=FALSE, allowedClasses="character")
-          checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", isOutline, missing(isOutline), allowMissing=TRUE, allowNull=FALSE, allowedClasses="logical")
+          checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", styleAsOutline, missing(styleAsOutline), allowMissing=TRUE, allowNull=FALSE, allowedClasses="logical")
           checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", outlineCellStyle, missing(outlineCellStyle), allowMissing=TRUE, allowNull=FALSE, allowedClasses="character")
           checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", mergeCells, missing(mergeCells), allowMissing=TRUE, allowNull=FALSE, allowedClasses="logical")
           checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotHtmlRenderer", "getCellsInRowHtml", rowGroupCellBaseStyleName, missing(rowGroupCellBaseStyleName), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
@@ -355,7 +354,7 @@ PivotHtmlRenderer <- R6::R6Class("PivotHtmlRenderer",
          # special case of all the cells being merged
          cssCell <- cellStyle
          if(!is.null(rowGroupCellBaseStyleName)) cssCell <-  paste0(styleNamePrefix, rowGroupCellBaseStyleName)
-         else if(isOutline && !is.null(outlineCellStyle)) cssCell <- outlineCellStyle
+         else if(styleAsOutline && !is.null(outlineCellStyle)) cssCell <- outlineCellStyle
          cllstyl <- NULL
          if(!is.null(rowGroupCellStyle)) cllstyl <- rowGroupCellStyle$asCSSRule()
          trowcells[[length(trowcells)+1]] <- htmltools::tags$td(class=cssCell, style=cllstyl, colspan=columnCount, htmltools::HTML("&nbsp;"))
@@ -363,15 +362,38 @@ PivotHtmlRenderer <- R6::R6Class("PivotHtmlRenderer",
        else {
          # normal case
          for(c in 1:columnCount) {
+            # get the cell
             cell <- private$p_parentPivot$cells$getCell(r, c)
+            # get the column group
+            columnGroup <- private$p_parentPivot$getLeafColumnGroup(c=c)
+            # base style name precedence:  from the cell, from the column group, from the row group,
+            #                              then default outline (if outline), default total (if total), default cell
+            cgBaseStyleName <- columnGroup$netCellBaseStyleName
             if(!is.null(cell$baseStyleName)) cssCell <- paste0(styleNamePrefix, cell$baseStyleName)
+            else if(!is.null(cgBaseStyleName)) cssCell <- paste0(styleNamePrefix, cgBaseStyleName)
             else if(!is.null(rowGroupCellBaseStyleName)) cssCell <- paste0(styleNamePrefix, rowGroupCellBaseStyleName)
-            else if(isOutline && (!is.null(outlineCellStyle))) cssCell <- outlineCellStyle
+            else if(styleAsOutline && (!is.null(outlineCellStyle))) cssCell <- outlineCellStyle
             else if(cell$isTotal) cssCell <- totalStyle
             else cssCell <- cellStyle
+            # style overrides precedence:  from the cell, from the column group, from the row group
+            #                              given these styles are not single values, but lists of declarations, the styles
+            #                              aggregate via a set operation, i.e. intersect/union from row -> col -> cell
             cllstyl <- NULL
-            if(!is.null(cell$style)) cllstyl <- cell$style$asCSSRule()
-            else if (!is.null(rowGroupCellStyle)) cllstyl <- rowGroupCellStyle$asCSSRule()
+            if(!is.null(rowGroupCellStyle)) {
+               if(is.null(cllstyl)) { cllstyl <- rowGroupCellStyle$getCopy("") }
+               else { cllstyl$setPropertyValues(rowGroupCellStyle$declarations) }
+            }
+            colGroupStyle <- columnGroup$netCellStyle
+            if(!is.null(colGroupStyle)) {
+               if(is.null(cllstyl)) { cllstyl <- colGroupStyle$getCopy("") }
+               else { cllstyl$setPropertyValues(colGroupStyle$declarations) }
+            }
+            if(!is.null(cell$style)) {
+               if(is.null(cllstyl)) { cllstyl <- cell$style$getCopy("") }
+               else { cllstyl$setPropertyValues(cell$style$declarations) }
+            }
+            if(!is.null(cllstyl)) cllstyl <- cllstyl$asCSSRule()
+            # render the cell
             detail <- list()
             if(includeRCFilters|includeCalculationFilters|includeWorkingData|includeEvaluationFilters|includeCalculationNames|includeRawValue)
             {
